==========
User Guide
==========

We recommend checking out the `Radar Cookbook <https://cookbooks.projectpythia.org/radar-cookbook/README.html>`_ to get started!

We also have a collection of installation, and contribution instructions listed below.

.. toctree::
   :maxdepth: 1

   INSTALL
   setting_up_an_environment
   contributors_guide
